@@ -624,16 +624,25 @@ sub tabbinder {
                 $w->draw;
                 $w->modalfocus;
                 $this->parent->delete("accountselection");
-                unless ($escapeit) {
+                $this->parent->draw();
+                if ($escapeit) {
+                    $editcell = 1;
+                    $datacoll = 0;
+                }
+                else {
                     if (defined $w->{-selected}) {
-                        if (defined $matrixdata->{"CD.$dc.$dr"}->{"Blurcallback"}) {
-                            $matrixwidget->{"VC.$vc.$vr"}->{-text} = $accounts->[$w->{-selected}];
-                            &{$matrixdata->{"CD.$dc.$dr"}->{"Blurcallback"}}($matrixwidget, $dc, $dr, $vc, $vr);
-                        }
+                        $matrixwidget->{"VC.$vc.$vr"}->{-text} = $accounts->[$w->{-selected}];
+                        $editcell = 0;
+                        $datacoll = 1;
+                    }
+                    else {
+                        $editcell = 1;
+                        $datacoll = 0;
+                    }
+                    if (defined $matrixdata->{"CD.$dc.$dr"}->{"Blurcallback"}) {
+                        &{$matrixdata->{"CD.$dc.$dr"}->{"Blurcallback"}}($matrixwidget, $dc, $dr, $vc, $vr);
                     }
                 }
-                $editcell = 0;
-                $datacoll = 1;
             }
         }
     }
@@ -1025,6 +1034,10 @@ sub keybinder {
         }
         $this->root->feedkey(KEY_F(2)); #enter edit mode after datacoll was handled
         # implicit immediate KEY_DOWN
+        &layoutmatrixwidget();
+        $datacoll = 0;
+        &drawfocusmatrixwidget();
+        $nvr = $matrixwidget->{"NumVisualRow"} - 1;
         $vr++;
         if ($vr > $nvr) {
             $vrscroll = 1;
@@ -1318,6 +1331,7 @@ sub commonquit() {
     if (    not $matrixdata->{"dirty"} 
          or $cui->dialog(-message => " Quit without saving? \n" .
                                      " Changes will be lost ",
+                         -selected => 1,
                          -buttons => [
                                           { -label => "[ OK ]",     -value => 1 },
                                           { -label => "[ Cancel ]", -value => 0 }
@@ -1491,6 +1505,7 @@ sub ascuido {
         $vrpos    = 0;
 
         &statusline() unless($editcell);
+        $cui->root->accessor(-cursor_mode => $editcell);
         $cui->root->do_one_event;
 
         if    ($vcscroll < 0) {
